TokenWriter

Trait TokenWriter 

pub trait TokenWriter {
    // Required method
    fn write_tokens(&mut self, tokens: &[Token]) -> Result<(), CSVError>;
}
A Token Writer writes the set of specified tokens to the output stream

Required Methods

fn write_tokens(&mut self, tokens: &[Token]) -> Result<(), CSVError>

Attempts to write these tokens to the output stream.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors